@@ -5,7 +5,7 @@ use Carp ();
 
 require Email::Simple;
 
-$Email::Simple::Header::VERSION = '2.005';
+$Email::Simple::Header::VERSION = '2.101';
 
 =head1 NAME
 
@@ -312,7 +312,7 @@ sub _default_fold_indent { " " }
 
 This module is maintained by the Perl Email Project
 
-L<http://emailproject.perl.org/wiki/Email::Simple::Header>
+L<http://emailproject.perl.org/>
 
 =head1 COPYRIGHT AND LICENSE
 
